@@ -1,9 +1,9 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 
 import GeoIP
 
 gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPOrg.dat",GeoIP.GEOIP_STANDARD)
 
 print gi.org_by_name("yahoo.com")
-print gi.org_by_name("www.government.de")
-print gi.org_by_addr("203.195.93.0")
+print gi.org_by_name("www.google.com")
+print gi.org_by_addr("24.24.24.24")
